==> tsibble_0.1.0.tar.gz: tsibble/R/reexports.R <==
#' @importFrom dplyr group_size
#' @export
dplyr::group_size

#' @importFrom dplyr n_groups
#' @export
dplyr::n_groups

#' @importFrom dplyr group_indices
#' @export
dplyr::group_indices

#' @importFrom dplyr group_vars
#' @export
dplyr::group_vars

#' @importFrom dplyr groups
#' @export
dplyr::groups

#' @importFrom dplyr ungroup
#' @export
dplyr::ungroup

#' @importFrom dplyr group_by
#' @export
dplyr::group_by

#' @importFrom dplyr mutate
#' @export
dplyr::mutate

#' @importFrom dplyr filter
#' @export
dplyr::filter

#' @importFrom dplyr slice
#' @export
dplyr::slice

#' @importFrom dplyr select
#' @export
dplyr::select

#' @importFrom dplyr rename
#' @export
dplyr::rename

#' @importFrom dplyr arrange
#' @export
dplyr::arrange

#' @importFrom dplyr summarise
#' @export
dplyr::summarise

#' @importFrom dplyr summarize
#' @export
dplyr::summarize

#' @importFrom dplyr %>%
#' @export
dplyr::`%>%`

#' @importFrom tibble glimpse
#' @export
tibble::glimpse

#' @importFrom tibble tbl_sum
#' @export
tibble::tbl_sum

#' @importFrom tibble as_tibble
#' @export
tibble::as_tibble

#' @importFrom tibble as.tibble
#' @export
tibble::as.tibble

#' @importFrom rlang !!
#' @export
rlang::`!!`

#' @importFrom rlang !!!
#' @export
rlang::`!!!`

#' @importFrom pillar type_sum
#' @export
pillar::type_sum

#' @importFrom pillar obj_sum
#' @export
pillar::obj_sum

#' @importFrom pillar is_vector_s3
#' @export
pillar::is_vector_s3

#' @importFrom pillar pillar_shaft
#' @export
pillar::pillar_shaft

==> tsibble_0.1.2.tar.gz: tsibble/R/reexports.R <==
#' @importFrom dplyr group_size
#' @export
dplyr::group_size

#' @importFrom dplyr n_groups
#' @export
dplyr::n_groups

#' @importFrom dplyr group_indices
#' @export
dplyr::group_indices

#' @importFrom dplyr group_vars
#' @export
dplyr::group_vars

#' @importFrom dplyr groups
#' @export
dplyr::groups

#' @importFrom dplyr ungroup
#' @export
dplyr::ungroup

#' @importFrom dplyr group_by
#' @export
dplyr::group_by

#' @importFrom dplyr mutate
#' @export
dplyr::mutate

#' @importFrom dplyr filter
#' @export
dplyr::filter

#' @importFrom dplyr slice
#' @export
dplyr::slice

#' @importFrom dplyr select
#' @export
dplyr::select

#' @importFrom dplyr rename
#' @export
dplyr::rename

#' @importFrom dplyr arrange
#' @export
dplyr::arrange

#' @importFrom dplyr summarise
#' @export
dplyr::summarise

#' @importFrom dplyr summarize
#' @export
dplyr::summarize

#' @importFrom dplyr do
#' @export
dplyr::do

#' @importFrom dplyr transmute
#' @export
dplyr::transmute

#' @importFrom dplyr distinct
#' @export
dplyr::distinct

#' @importFrom dplyr full_join
#' @export
dplyr::full_join

#' @importFrom dplyr inner_join
#' @export
dplyr::inner_join

#' @importFrom dplyr left_join
#' @export
dplyr::left_join

#' @importFrom dplyr right_join
#' @export
dplyr::right_join

#' @importFrom dplyr semi_join
#' @export
dplyr::semi_join

#' @importFrom dplyr anti_join
#' @export
dplyr::anti_join

#' @importFrom dplyr %>%
#' @export
dplyr::`%>%`

#' @importFrom tidyr fill
#' @export
tidyr::fill

#' @importFrom tibble glimpse
#' @export
tibble::glimpse

#' @importFrom tibble tbl_sum
#' @export
tibble::tbl_sum

#' @importFrom tibble as_tibble
#' @export
tibble::as_tibble

#' @importFrom tibble as.tibble
#' @export
tibble::as.tibble

#' @importFrom rlang !!
#' @export
rlang::`!!`

#' @importFrom rlang !!!
#' @export
rlang::`!!!`

#' @importFrom pillar type_sum
#' @export
pillar::type_sum

#' @importFrom pillar obj_sum
#' @export
pillar::obj_sum

#' @importFrom pillar is_vector_s3
#' @export
pillar::is_vector_s3

#' @importFrom pillar pillar_shaft
#' @export
pillar::pillar_shaft
